@@ -33,5 +33,5 @@ class ProcessorService(processor_pb2_grpc.ProcessorServicer):
             )
 
         yield FlowExecuteResponse(
-            data=None, attributes=None, streamEnd=True
+            content=None, attributes=None, streamEnd=True
         )
